@@ -61,7 +61,11 @@ def get_all_files(path):
   return get_tracked_files([repo.tree()])
 
 
-def add_copyright(path):
+def main():
+  if len(sys.argv) != 2:
+    print("Please enter the path to the root of your Git repository"
+
+  path = sys.argv[1]
   copyright_file_map = get_copyright_files_map(path)
   file_name: str
   for file_name in get_all_files(path):
@@ -88,3 +92,4 @@ def add_copyright(path):
 
 if __name__ == "__main__":
     add_copyright(sys.argv[1])
+    sys.exit(main())  # pragma: no cover
